@@ -7,6 +7,6 @@ from tests import views
 urlpatterns = [
     path("", views.TestView.as_view(), name="test"),
     path('admin/', admin.site.urls),
-    path("glue/", include('django_glue.urls', namespace='django_glue')),
+    path("django_glue/", include('django_glue.urls', namespace='django_glue')),
     path("no_glue/", TemplateView.as_view(template_name='no_glue.html'), name="no_glue"),
 ]
\ No newline at end of file
